@@ -1,24 +1,25 @@
 import React from 'react';
 
-import { JobsPanelView } from '../notebook-jobs-panel';
+import { JobsView } from '../model';
 
-export interface tabClickProps {
-  (event: React.MouseEvent<HTMLElement, MouseEvent>, view: JobsPanelView): void;
-}
+export type tabClickProps = (
+  event: React.MouseEvent<HTMLElement, MouseEvent>,
+  view: JobsView
+) => void;
 
 export function NotebookJobsNavigationTab(props: {
   onClick: tabClickProps;
-  id: JobsPanelView;
+  id: JobsView;
   title: string;
   active: boolean;
-}) {
+}): JSX.Element {
   return (
     <li
       id={props.id}
       className={
         'jp-notebook-job-navigation-tab' + (props.active ? ' active' : '')
       }
-      onClick={props.active ? () => {} : e => props.onClick(e, props.id)}
+      onClick={props.active ? undefined : e => props.onClick(e, props.id)}
     >
       {props.title}
     </li>
