@@ -42,6 +42,22 @@ export class SchedulerService {
     return data as Scheduler.IDescribeJobDefinition;
   }
 
+  async getJob(job_id: string): Promise<Scheduler.IDescribeJob> {
+    let data;
+    let query = '';
+
+    query = `/${job_id}`;
+
+    try {
+      data = await requestAPI(this.serverSettings, `jobs${query}`, {
+        method: 'GET'
+      });
+    } catch (e: any) {
+      console.error(e);
+    }
+    return data as Scheduler.IDescribeJob;
+  }
+
   async getJobs(
     jobQuery: Scheduler.IListJobsQuery,
     job_id?: string
@@ -57,19 +73,26 @@ export class SchedulerService {
         Object.keys(jobQuery)
           .map(prop => {
             if (prop === 'sort_by') {
-              if (jobQuery[prop] === undefined) {
+              const sortList: Scheduler.ISortField[] | undefined =
+                jobQuery.sort_by;
+              if (sortList === undefined) {
                 return null;
               }
+
               // Serialize sort_by as a series of parameters in the firm dir(name)
               // where 'dir' is the direction and 'name' the sort field
-              return jobQuery[prop]!.map(
-                sort =>
-                  `sort_by=${encodeURIComponent(
-                    sort.direction
-                  )}(${encodeURIComponent(sort.name)})`
-              ).join('&');
+              return sortList
+                .map(
+                  sort =>
+                    `sort_by=${encodeURIComponent(
+                      sort.direction
+                    )}(${encodeURIComponent(sort.name)})`
+                )
+                .join('&');
             }
-            //@ts-ignore
+
+            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
+            // @ts-ignore
             const value = jobQuery[prop];
             return `${encodeURIComponent(prop)}=${encodeURIComponent(value)}`;
           })
@@ -86,7 +109,7 @@ export class SchedulerService {
     return data as Scheduler.IListJobsResponse;
   }
 
-  async getJobsCount(status?: string): Promise<number> {
+  async getjobCount(status?: string): Promise<number> {
     let data: { count: number } = { count: 0 }; // Fail safe
     let query = '';
     if (status) {
@@ -149,7 +172,7 @@ export class SchedulerService {
     return data as Scheduler.IRuntimeEnvironment[];
   }
 
-  async deleteJob(job_id: string) {
+  async deleteJob(job_id: string): Promise<void> {
     try {
       await requestAPI(this.serverSettings, `jobs/${job_id}`, {
         method: 'DELETE'
@@ -222,7 +245,7 @@ export namespace Scheduler {
     name?: string;
   }
 
-  export interface IUpdateJobDefinition extends IBaseJobDefinition {}
+  export type IUpdateJobDefinition = IBaseJobDefinition;
 
   export interface IDescribeJobDefinition extends IBaseJobDefinition {
     job_definition_id: string;
@@ -302,6 +325,7 @@ export namespace Scheduler {
   export interface IListJobsResponse {
     jobs: IDescribeJob[];
     next_token?: string;
+    total_count: number;
   }
 
   export interface IRuntimeEnvironment {
